@@ -1,4 +1,4 @@
-// $Id: genres.h,v 1.8 2006/04/24 20:00:20 khlut Exp $
+// $Id: genres.h,v 1.9 2006/05/13 20:57:46 khlut Exp $
 // Copyright 2005 Elphel, Inc.
 //
 // This file is part of GenReS.
@@ -97,5 +97,5 @@ char *strpath(char *_path);
 char *pair(char **s, const char *spaces, const char *delims, const char *eols);
 void configure();
 
-extern int debug, mozillastreams;
+extern int debug, mozillastreams, background;
 #define Debug debug&&printf
